# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.0-alpha.6](https://github.com/lox-space/lox/compare/lox-bodies-v0.1.0-alpha.5...lox-bodies-v0.1.0-alpha.6) - 2025-02-10

### Other

- update Cargo.toml dependencies

## [0.1.0-alpha.5](https://github.com/lox-space/lox/compare/lox-bodies-v0.1.0-alpha.4...lox-bodies-v0.1.0-alpha.5) - 2025-01-24

### Other

- simplify rotational elements

## [0.1.0-alpha.4](https://github.com/lox-space/lox/compare/lox-bodies-v0.1.0-alpha.3...lox-bodies-v0.1.0-alpha.4) - 2024-12-19

### Fixed

- fix switched radii

## [0.1.0-alpha.3](https://github.com/lox-space/lox/compare/lox-bodies-v0.1.0-alpha.2...lox-bodies-v0.1.0-alpha.3) - 2024-12-19

### Other

- prefer `Result` over `Option` for `Origin` props

## [0.1.0-alpha.2](https://github.com/lox-space/lox/compare/lox-bodies-v0.1.0-alpha.1...lox-bodies-v0.1.0-alpha.2) - 2024-12-18

### Other

- implement dynamic origin and frame types

## [0.1.0-alpha.1](https://github.com/lox-space/lox/compare/lox-bodies-v0.1.0-alpha.0...lox-bodies-v0.1.0-alpha.1) - 2024-11-12

### Other

- update Cargo.toml dependencies

## [0.1.0-alpha.0](https://github.com/lox-space/lox/releases/tag/lox-bodies-v0.1.0-alpha.0) - 2024-07-19

### Other
- Rename lox-utils to lox-math because the former is taken ([#146](https://github.com/lox-space/lox/pull/146))
- Add crate descriptions ([#145](https://github.com/lox-space/lox/pull/145))
- Align versions ([#143](https://github.com/lox-space/lox/pull/143))
- Fix bodyfixed frames for satellites
- Fix Python ground propagator
- Implement visibility window detection
- Implement ground propagator
- Impl event and window detection from Python
- Expose `Frame` class from Python
- Fix transformations
- Prototype trajectory
- Implement ICRF <-> body-fixed transformations
- Prototype orbit state representations
- Move Python wrappers to `lox-bodies` ([#107](https://github.com/lox-space/lox/pull/107))
- Hoist shared constants and type aliases ([#84](https://github.com/lox-space/lox/pull/84))
- Implement TAI <-> UTC conversion ([#81](https://github.com/lox-space/lox/pull/81))
- Core No More ([#68](https://github.com/lox-space/lox/pull/68))
